@@ -10,11 +10,16 @@ def compile(for_debugging=False, force_rebuild=False):
 	import vectorian.core
 
 
+def set_verbose(level):
+	os.environ["VECTORIAN_VERBOSE"] = str(level)
+
+
 import vectorian.embeddings as embeddings
 import vectorian.importers as importers
 import vectorian.session as session
 import vectorian.metrics as metrics
 import vectorian.alignment as alignment
+import vectorian.saliency as booster
 
 # "metrics" is the older name, "similarity" the newer name
 similarity = metrics
