@@ -1,6 +1,6 @@
 import vectorian.core as core
+from vectorian.tqdm import tqdm
 
-from tqdm.autonotebook import tqdm
 from pathlib import Path
 from cached_property import cached_property
 from functools import partial
@@ -86,13 +86,17 @@ def _download(url, path, force_download=False):
 			raise
 
 	if download_path != result_path:
+		extracted = []
 		with zipfile.ZipFile(download_path, 'r') as zf:
 			for zi in zf.infolist():
 				if zi.filename[-1] == '/':
 					continue
 				zi.filename = os.path.basename(zi.filename)
 				p = zf.extract(zi, result_path.parent)
-				Path(p).rename(result_path)
+				extracted.append(Path(p))
+
+		if len(extracted) == 1:
+			extracted[0].rename(result_path)
 
 		download_path.unlink()
 
@@ -600,6 +604,18 @@ class Word2VecVectors(GensimVectors):
 			self._path, binary=self._binary)
 
 
+class OneHotEncoding(StaticEmbedding):
+	class Instance(StaticEmbeddingInstance):
+		pass
+
+	def create_instance(self, session):
+		return OneHotEncoding.Instance()
+
+	@property
+	def name(self):
+		return "one-hot"
+
+
 class KeyedVectors(StaticEmbedding):
 	# using this class directly circumvents Vectorian's token
 	# normalization. use with care.
@@ -966,7 +982,7 @@ class ContextualEmbedding(Embedding):
 		raise NotImplementedError()
 
 
-class SpacyEmbedding(ContextualEmbedding):
+class AbstractSpacyEmbedding(ContextualEmbedding):
 	def __init__(self, nlp, transform=None):
 		super().__init__(transform)
 		self._nlp = nlp
@@ -1031,7 +1047,7 @@ class VectorCache:
 			return np.load(self._path / (stem + ".npy"))
 
 
-class SpacyVectorEmbedding(SpacyEmbedding):
+class SpacyEmbedding(AbstractSpacyEmbedding):
 	def __init__(self, nlp, dimension, cache=None, **kwargs):
 		super().__init__(nlp, **kwargs)
 		self._dimension = dimension
@@ -1042,7 +1058,7 @@ class SpacyVectorEmbedding(SpacyEmbedding):
 		return self._dimension
 
 	def pca(self, n_dims):
-		return SpacyVectorEmbedding(self._nlp, PCACompression(n_dims))
+		return SpacyEmbedding(self._nlp, PCACompression(n_dims))
 
 	def encode(self, doc):
 		if self._cache is not None:
@@ -1050,7 +1066,7 @@ class SpacyVectorEmbedding(SpacyEmbedding):
 			if array is not None:
 				return array
 
-		array = np.array([token.vector for token in doc])
+		array = np.array([token.vector for token in self._nlp(doc.text)])
 
 		if self._cache is not None:
 			self._cache.put(doc.text, array)
@@ -1058,7 +1074,7 @@ class SpacyVectorEmbedding(SpacyEmbedding):
 		return array
 
 
-class SpacyTransformerEmbedding(SpacyEmbedding):
+class SpacyTransformerEmbedding(AbstractSpacyEmbedding):
 	@property
 	def dimension(self):
 		if self._transform is not None:
