@@ -14,10 +14,11 @@ import os
 
 from cached_property import cached_property
 from collections import namedtuple
-from tqdm.autonotebook import tqdm
 from pathlib import Path
+
 from vectorian.corpus.document import TokenTable, InternalMemoryText
 from vectorian.embeddings import Vectors, ProxyVectorsRef, prepare_docs
+from vectorian.tqdm import tqdm
 
 
 class Query:
@@ -315,7 +316,7 @@ class CoreMatch(Match):
 
 	@property
 	def score(self):
-		return self._c_match.score_nrm
+		return self._c_match.score_val
 
 	@property
 	def score_max(self):
@@ -504,7 +505,7 @@ class DummyIndex(Index):
 
 
 class BruteForceIndex(Index):
-	def __init__(self, *args, nlp, **kwargs):
+	def __init__(self, *args, nlp, saliency=None, **kwargs):
 		super().__init__(*args, **kwargs)
 		self._nlp = nlp
 
@@ -514,16 +515,24 @@ class BruteForceIndex(Index):
 		else:
 			self._max_threads = max(1, int(self._max_threads))
 
+		self._saliency = {}
+		if saliency:
+			for doc in self.session.documents:
+				self._saliency[doc.compiled.id] = saliency.compile(
+					doc, self.partition)
+
+	def _find_in_doc(self, doc, c_query):
+		saliency = self._saliency.get(doc.id)
+		return doc, doc.find(c_query, saliency)
+
 	def _find(self, query, n_threads=None, progress=None):
 		p_query = query.prepare(self._nlp)
 
 		if len(p_query) == 0:
 			return []
 
-		c_query = p_query.compiled
-
-		def find_in_doc(x):
-			return x, x.find(c_query)
+		find_in_doc = functools.partial(
+			self._find_in_doc, c_query=p_query.compiled)
 
 		docs = self.session.c_documents
 
