@@ -1,7 +1,7 @@
-from vectorian.sim.vector import VectorSimilarity
+from vectorian.sim.vector import VectorSim
 
 
-class AbstractTokenSimilarity:
+class AbstractTokenSim:
 	@property
 	def is_modifier(self):
 		return False
@@ -15,8 +15,8 @@ class AbstractTokenSimilarity:
 		raise NotImplementedError()
 
 
-class TokenSimilarity(AbstractTokenSimilarity):
-	def __init__(self, embedding, sim: VectorSimilarity):
+class TokenSim(AbstractTokenSim):
+	def __init__(self, embedding, sim: VectorSim):
 		self._embedding = embedding
 		self._sim = sim
 
